@@ -26,3 +26,10 @@ class ForbiddenException(HarmonyException):
 
     def __init__(self, message=None):
         super().__init__(message, 'Forbidden')
+
+
+class ServerException(HarmonyException):
+    """Class for throwing an exception indicating the download failed due to a generic 500 internal server error """
+
+    def __init__(self, message=None):
+        super().__init__(message, 'Server')
